@@ -41,8 +41,6 @@ typedef enum {
 
 GList      *_geocode_parse_search_json  (const char *contents,
 					 GError    **error);
-GeocodeLocation *_geocode_ip_json_to_location (const char  *json,
-					       GError     **error);
 void
 _geocode_read_nominatim_attributes (JsonReader *reader,
                                     GHashTable *ht);
@@ -57,9 +55,7 @@ gboolean _geocode_glib_cache_save (SoupMessage *query,
 gboolean _geocode_glib_cache_load (SoupMessage *query,
                                    char       **contents);
 GHashTable *_geocode_glib_dup_hash_table (GHashTable *ht);
-
-void _geocode_place_set_icon      (GeocodePlace *place,
-                                   GIcon        *icon);
+SoupSession *_geocode_glib_build_soup_session (void);
 
 G_END_DECLS
 
